==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ewo.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ewo extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Dir\u00e1m y\u00e1 Emir\u00e1 Ar\u00e1b Un\u00ed" },
            { "aoa", "Kw\u00e1n\u0259za y\u00e1 Angol\u00e1" },
            { "aud", "Dol\u00e1r y\u00e1 Os\u0259t\u0259ral\u00ed" },
            { "bhd", "Din\u00e1r y\u00e1 Bah\u0259r\u025b\u0301n" },
            { "bif", "F\u0259l\u00e1\u014b y\u00e1 Burund\u00ed" },
            { "bwp", "P\u00fal\u00e1 y\u00e1 Botsw\u00e1na" },
            { "cad", "Dol\u00e1r y\u00e1 Kan\u00e1da" },
            { "cdf", "F\u0259l\u00e1\u014b y\u00e1 Kongo" },
            { "chf", "F\u0259l\u00e1\u014b y\u00e1 Su\u00eds" },
            { "cny", "Yu\u00e1n Ren\u0259min\u0259b\u00ed y\u00e1 Tsain\u00eds" },
            { "cve", "Es\u0259k\u00fado y\u00e1 K\u00e1p\u0259\u0301v\u025b\u0301r\u0259" },
            { "djf", "F\u0259l\u00e1\u014b y\u00e1 dzibut\u00ed" },
            { "dzd", "Din\u00e1r y\u00e1 Aleh\u00e9r\u00ed" },
            { "egp", "L\u00edv\u0259\u0301l\u0259 y\u00e1 Eh\u00edb\u0259t\u00eda" },
            { "ern", "N\u00e1f\u0259ka y\u00e1 Eritel\u00e9" },
            { "etb", "B\u00edr y\u00e1 Etsi\u00f3pia" },
            { "eur", "\u0259r\u00f3" },
            { "gbp", "L\u00edv\u0259\u0301l\u0259 S\u0259t\u0259r\u0259l\u00ed\u014b" },
            { "ghc", "Tzed\u00ed y\u00e1 Gan\u00e1" },
            { "gmd", "Dalas\u00ed y\u00e1 G\u00e1mb\u00eda" },
            { "gns", "S\u00edli y\u00e1 Gin\u00e9" },
            { "inr", "Rup\u00ed y\u00e1 \u025b\u0301nd\u00eda" },
            { "jpy", "Y\u025b\u0301n y\u00e1 Hap\u0254\u0301n" },
            { "kes", "Sil\u00ed\u014b y\u00e1 Keni\u00e1" },
            { "kmf", "F\u0259l\u00e1\u014b y\u00e1 Kom\u00f3ria" },
            { "lrd", "Dol\u00e1r y\u00e1 Lib\u00e9ria" },
            { "lsl", "Lot\u00ed y\u00e1 Lesot\u00f3" },
            { "lyd", "Din\u00e1r y\u00e1 Lib\u00ed" },
            { "mad", "Dir\u00e1m y\u00e1 Mar\u00f3g" },
            { "mga", "Ariari y\u00e1 Mal\u0259g\u00e1s" },
            { "mro", "Ugiya y\u00e1 Moritan\u00ed (1973\u20132017)" },
            { "mru", "Ugiya y\u00e1 Moritan\u00ed" },
            { "mur", "Rup\u00ed y\u00e1 Mor\u00eds" },
            { "mwk", "Kwatsa y\u00e1 Malaw\u00ed" },
            { "mzm", "Metikal y\u00e1 Mozamb\u00edg" },
            { "nad", "Dol\u00e1r y\u00e1 Namib\u00ed" },
            { "ngn", "N\u00e1\u00edra y\u00e1 Nih\u00e9ria" },
            { "rwf", "F\u0259l\u00e1\u014b y\u00e1 Ruwand\u00e1" },
            { "sar", "Ri\u00e1l y\u00e1 Arab\u00ed Saud\u00ed" },
            { "scr", "Rup\u00ed y\u00e1 S\u025bs\u025b\u0301l" },
            { "sdg", "L\u00edv\u0259l\u0259 y\u00e1 Sud\u00e1n" },
            { "sdp", "L\u00edv\u0259l\u0259 y\u00e1 Sud\u00e1n (1956\u20132007)" },
            { "shp", "L\u00edv\u0259l\u0259 y\u00e1 \u01f8f\u00faf\u00fab El\u025b\u0301n" },
            { "sll", "Le\u00f3ne y\u00e1 Sier\u00e1-le\u00f3n\u0259" },
            { "sos", "Sil\u00ed\u014b y\u00e1 Somal\u00ed" },
            { "std", "D\u00f3b\u0259\u0301ra y\u00e1 Sa\u00f3 Tom\u00e9 ai P\u0259lin\u0259s\u00edpe (1977\u20132017)" },
            { "stn", "D\u00f3b\u0259\u0301ra y\u00e1 Sa\u00f3 Tom\u00e9 ai P\u0259lin\u0259s\u00edpe" },
            { "szl", "Lilangeni y\u00e1 Swaz\u00ed" },
            { "tnd", "Din\u00e1r y\u00e1 Tunis\u00ed" },
            { "tzs", "Sil\u00ed\u014b y\u00e1 Tanazan\u00ed" },
            { "ugx", "Sil\u00ed\u014b y\u00e1 Ugand\u00e1 (1966\u20131987)" },
            { "usd", "Dol\u00e1r y\u00e1 am\u025b\u0301r\u0259k\u0259" },
            { "xaf", "F\u0259l\u00e1\u014b CFA (BEAC)" },
            { "xof", "F\u0259l\u00e1\u014b CFA (BCEAO)" },
            { "zar", "R\u00e1n\u0259d\u0259 y\u00e1 Afir\u00edka" },
            { "zmk", "Kwatsa y\u00e1 Zamb\u00ed (1968\u20132012)" },
            { "zmw", "Kwatsa y\u00e1 Zamb\u00ed" },
            { "zwd", "Dol\u00e1r y\u00e1 Zimbabw\u00e9" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ewo.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ewo extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Dir\u00e1m y\u00e1 Emir\u00e1 Ar\u00e1b Un\u00ed" },
            { "aoa", "Kw\u00e1n\u0259za y\u00e1 Angol\u00e1" },
            { "aud", "Dol\u00e1r y\u00e1 Os\u0259t\u0259ral\u00ed" },
            { "bhd", "Din\u00e1r y\u00e1 Bah\u0259r\u025b\u0301n" },
            { "bif", "F\u0259l\u00e1\u014b y\u00e1 Burund\u00ed" },
            { "bwp", "P\u00fal\u00e1 y\u00e1 Botsw\u00e1na" },
            { "cad", "Dol\u00e1r y\u00e1 Kan\u00e1da" },
            { "cdf", "F\u0259l\u00e1\u014b y\u00e1 Kongo" },
            { "chf", "F\u0259l\u00e1\u014b y\u00e1 Su\u00eds" },
            { "cny", "Yu\u00e1n Ren\u0259min\u0259b\u00ed y\u00e1 Tsain\u00eds" },
            { "cve", "Es\u0259k\u00fado y\u00e1 K\u00e1p\u0259\u0301v\u025b\u0301r\u0259" },
            { "djf", "F\u0259l\u00e1\u014b y\u00e1 dzibut\u00ed" },
            { "dzd", "Din\u00e1r y\u00e1 Aleh\u00e9r\u00ed" },
            { "egp", "L\u00edv\u0259\u0301l\u0259 y\u00e1 Eh\u00edb\u0259t\u00eda" },
            { "ern", "N\u00e1f\u0259ka y\u00e1 Eritel\u00e9" },
            { "etb", "B\u00edr y\u00e1 Etsi\u00f3pia" },
            { "eur", "\u0259r\u00f3" },
            { "gbp", "L\u00edv\u0259\u0301l\u0259 S\u0259t\u0259r\u0259l\u00ed\u014b" },
            { "ghc", "Tzed\u00ed y\u00e1 Gan\u00e1" },
            { "gmd", "Dalas\u00ed y\u00e1 G\u00e1mb\u00eda" },
            { "gns", "S\u00edli y\u00e1 Gin\u00e9" },
            { "inr", "Rup\u00ed y\u00e1 \u025b\u0301nd\u00eda" },
            { "jpy", "Y\u025b\u0301n y\u00e1 Hap\u0254\u0301n" },
            { "kes", "Sil\u00ed\u014b y\u00e1 Keni\u00e1" },
            { "kmf", "F\u0259l\u00e1\u014b y\u00e1 Kom\u00f3ria" },
            { "lrd", "Dol\u00e1r y\u00e1 Lib\u00e9ria" },
            { "lsl", "Lot\u00ed y\u00e1 Lesot\u00f3" },
            { "lyd", "Din\u00e1r y\u00e1 Lib\u00ed" },
            { "mad", "Dir\u00e1m y\u00e1 Mar\u00f3g" },
            { "mga", "Ariari y\u00e1 Mal\u0259g\u00e1s" },
            { "mro", "Ugiya y\u00e1 Moritan\u00ed (1973\u20132017)" },
            { "mru", "Ugiya y\u00e1 Moritan\u00ed" },
            { "mur", "Rup\u00ed y\u00e1 Mor\u00eds" },
            { "mwk", "Kwatsa y\u00e1 Malaw\u00ed" },
            { "mzm", "Metikal y\u00e1 Mozamb\u00edg" },
            { "nad", "Dol\u00e1r y\u00e1 Namib\u00ed" },
            { "ngn", "N\u00e1\u00edra y\u00e1 Nih\u00e9ria" },
            { "rwf", "F\u0259l\u00e1\u014b y\u00e1 Ruwand\u00e1" },
            { "sar", "Ri\u00e1l y\u00e1 Arab\u00ed Saud\u00ed" },
            { "scr", "Rup\u00ed y\u00e1 S\u025bs\u025b\u0301l" },
            { "sdg", "L\u00edv\u0259l\u0259 y\u00e1 Sud\u00e1n" },
            { "sdp", "L\u00edv\u0259l\u0259 y\u00e1 Sud\u00e1n (1956\u20132007)" },
            { "shp", "L\u00edv\u0259l\u0259 y\u00e1 \u01f8f\u00faf\u00fab El\u025b\u0301n" },
            { "sle", "Le\u00f3ne y\u00e1 Sier\u00e1-le\u00f3n\u0259" },
            { "sll", "Le\u00f3ne y\u00e1 Sier\u00e1-le\u00f3n\u0259 (1964\u20142022)" },
            { "sos", "Sil\u00ed\u014b y\u00e1 Somal\u00ed" },
            { "std", "D\u00f3b\u0259\u0301ra y\u00e1 Sa\u00f3 Tom\u00e9 ai P\u0259lin\u0259s\u00edpe (1977\u20132017)" },
            { "stn", "D\u00f3b\u0259\u0301ra y\u00e1 Sa\u00f3 Tom\u00e9 ai P\u0259lin\u0259s\u00edpe" },
            { "szl", "Lilangeni y\u00e1 Swaz\u00ed" },
            { "tnd", "Din\u00e1r y\u00e1 Tunis\u00ed" },
            { "tzs", "Sil\u00ed\u014b y\u00e1 Tanazan\u00ed" },
            { "ugx", "Sil\u00ed\u014b y\u00e1 Ugand\u00e1 (1966\u20131987)" },
            { "usd", "Dol\u00e1r y\u00e1 am\u025b\u0301r\u0259k\u0259" },
            { "xaf", "F\u0259l\u00e1\u014b CFA (BEAC)" },
            { "xof", "F\u0259l\u00e1\u014b CFA (BCEAO)" },
            { "zar", "R\u00e1n\u0259d\u0259 y\u00e1 Afir\u00edka" },
            { "zmk", "Kwatsa y\u00e1 Zamb\u00ed (1968\u20132012)" },
            { "zmw", "Kwatsa y\u00e1 Zamb\u00ed" },
            { "zwd", "Dol\u00e1r y\u00e1 Zimbabw\u00e9" },
        };
        return data;
    }
}
